@@ -225,7 +225,7 @@ sub _draw_with {
     my $async = $args{async};
     my ($gnuplot_process, $terminator_guard);
     if(!defined($writer)) {
-        $gnuplot_process = Gnuplot::Builder::Process->new;
+        $gnuplot_process = Gnuplot::Builder::Process->new(capture => !$async);
         $writer = $gnuplot_process->writer;
         $terminator_guard = $gnuplot_process->terminator_guard; ## stop the process if aborted.
     }
@@ -309,6 +309,8 @@ Gnuplot::Builder::Script - object-oriented builder for gnuplot script
 
 =head1 DESCRIPTION
 
+B<< This is a beta release. API may change in the future. >>
+
 L<Gnuplot::Builder::Script> is a builder object for a gnuplot script.
 
 The advantages of this module over just printing script text are:
